@@ -14,8 +14,6 @@
 // limitations under the License.
 //
 
-#include <grpc/support/port_platform.h>
-
 #include <stdint.h>
 
 #include <algorithm>
@@ -36,8 +34,8 @@
 #include <grpc/impl/channel_arg_names.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/log.h>
+#include <grpc/support/port_platform.h>
 
-#include "src/core/resolver/dns/event_engine/service_config_helper.h"
 #include "src/core/lib/config/core_configuration.h"
 #include "src/core/lib/debug/trace.h"
 #include "src/core/lib/gprpp/debug_location.h"
@@ -51,10 +49,11 @@
 #include "src/core/lib/iomgr/iomgr_fwd.h"
 #include "src/core/lib/iomgr/pollset_set.h"
 #include "src/core/lib/iomgr/resolved_address.h"
+#include "src/core/lib/uri/uri_parser.h"
+#include "src/core/resolver/dns/event_engine/service_config_helper.h"
 #include "src/core/resolver/resolver.h"
 #include "src/core/resolver/resolver_factory.h"
 #include "src/core/service_config/service_config.h"
-#include "src/core/lib/uri/uri_parser.h"
 
 #if GRPC_ARES == 1
 
@@ -66,12 +65,12 @@
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/config/config_vars.h"
 #include "src/core/lib/iomgr/resolve_address.h"
-#include "src/core/resolver/endpoint_addresses.h"
-#include "src/core/service_config/service_config_impl.h"
 #include "src/core/lib/transport/error_utils.h"
 #include "src/core/load_balancing/grpclb/grpclb_balancer_addresses.h"
 #include "src/core/resolver/dns/c_ares/grpc_ares_wrapper.h"
+#include "src/core/resolver/endpoint_addresses.h"
 #include "src/core/resolver/polling_resolver.h"
+#include "src/core/service_config/service_config_impl.h"
 
 #define GRPC_DNS_INITIAL_CONNECT_BACKOFF_SECONDS 1
 #define GRPC_DNS_RECONNECT_BACKOFF_MULTIPLIER 1.6
@@ -82,7 +81,7 @@ namespace grpc_core {
 
 namespace {
 
-class AresClientChannelDNSResolver : public PollingResolver {
+class AresClientChannelDNSResolver final : public PollingResolver {
  public:
   AresClientChannelDNSResolver(ResolverArgs args,
                                Duration min_time_between_resolutions);
@@ -90,7 +89,8 @@ class AresClientChannelDNSResolver : public PollingResolver {
   OrphanablePtr<Orphanable> StartRequest() override;
 
  private:
-  class AresRequestWrapper : public InternallyRefCounted<AresRequestWrapper> {
+  class AresRequestWrapper final
+      : public InternallyRefCounted<AresRequestWrapper> {
    public:
     explicit AresRequestWrapper(
         RefCountedPtr<AresClientChannelDNSResolver> resolver)
@@ -342,7 +342,7 @@ AresClientChannelDNSResolver::AresRequestWrapper::OnResolvedLocked(
 // Factory
 //
 
-class AresClientChannelDNSResolverFactory : public ResolverFactory {
+class AresClientChannelDNSResolverFactory final : public ResolverFactory {
  public:
   absl::string_view scheme() const override { return "dns"; }
 
@@ -365,7 +365,7 @@ class AresClientChannelDNSResolverFactory : public ResolverFactory {
   }
 };
 
-class AresDNSResolver : public DNSResolver {
+class AresDNSResolver final : public DNSResolver {
  public:
   // Abstract class that centralizes common request handling logic via the
   // template method pattern.
@@ -485,7 +485,7 @@ class AresDNSResolver : public DNSResolver {
     grpc_pollset_set* pollset_set_;
   };
 
-  class AresHostnameRequest : public AresRequest {
+  class AresHostnameRequest final : public AresRequest {
    public:
     AresHostnameRequest(
         absl::string_view name, absl::string_view default_port,
@@ -538,7 +538,7 @@ class AresDNSResolver : public DNSResolver {
     std::unique_ptr<EndpointAddressesList> addresses_;
   };
 
-  class AresSRVRequest : public AresRequest {
+  class AresSRVRequest final : public AresRequest {
    public:
     AresSRVRequest(
         absl::string_view name, absl::string_view name_server, Duration timeout,
@@ -586,7 +586,7 @@ class AresDNSResolver : public DNSResolver {
     std::unique_ptr<EndpointAddressesList> balancer_addresses_;
   };
 
-  class AresTXTRequest : public AresRequest {
+  class AresTXTRequest final : public AresRequest {
    public:
     AresTXTRequest(absl::string_view name, absl::string_view name_server,
                    Duration timeout, grpc_pollset_set* interested_parties,
