@@ -24,8 +24,8 @@
 #include <grpcpp/ext/csm_observability.h>
 #include <grpcpp/ext/otel_plugin.h>
 
-#include "src/core/ext/xds/xds_enabled_server.h"
-#include "test/core/util/test_config.h"
+#include "src/core/xds/grpc/xds_enabled_server.h"
+#include "test/core/test_util/test_config.h"
 
 namespace grpc {
 namespace testing {
@@ -77,15 +77,9 @@ TEST(CsmChannelTargetSelectorTest, CsmObservabilityOutOfScope) {
       "xds://traffic-director-global.xds.googleapis.com/foo"));
 }
 
-TEST(CsmServerSelectorTest, ChannelArgsWithoutXdsServerArg) {
+TEST(CsmServerSelectorTest, ChannelArgs) {
   auto obs = CsmObservabilityBuilder().BuildAndRegister();
-  EXPECT_FALSE(internal::CsmServerSelector(grpc_core::ChannelArgs()));
-}
-
-TEST(CsmServerSelectorTest, ChannelArgsWithXdsServerArg) {
-  auto obs = CsmObservabilityBuilder().BuildAndRegister();
-  EXPECT_TRUE(internal::CsmServerSelector(
-      grpc_core::ChannelArgs().Set(GRPC_ARG_XDS_ENABLED_SERVER, true)));
+  EXPECT_TRUE(internal::CsmServerSelector(grpc_core::ChannelArgs()));
 }
 
 TEST(CsmServerSelectorTest, CsmObservabilityOutOfScope) {
