@@ -284,7 +284,9 @@ class CLanguage(object):
                     "default",
                     "cmake",
                     "cmake_ninja_vs2019",
+                    "cmake_ninja_vs2022",
                     "cmake_vs2019",
+                    "cmake_vs2022",
                 ],
             )
             _check_arch(self.args.arch, ["default", "x64", "x86"])
@@ -299,8 +301,13 @@ class CLanguage(object):
                 # the compiler used is exactly the same as for cmake_vs2017
                 cmake_generator = "Ninja"
                 activate_vs_tools = "2019"
+            elif self.args.compiler == "cmake_ninja_vs2022":
+                cmake_generator = "Ninja"
+                activate_vs_tools = "2022"
             elif self.args.compiler == "cmake_vs2019":
                 cmake_generator = "Visual Studio 16 2019"
+            elif self.args.compiler == "cmake_vs2022":
+                cmake_generator = "Visual Studio 17 2022"
             else:
                 print("should never reach here.")
                 sys.exit(1)
@@ -531,6 +538,8 @@ class CLanguage(object):
             environ[
                 "GRPC_BUILD_VS_TOOLS_ARCHITECTURE"
             ] = self._vs_tools_architecture_windows
+        elif self.platform == "linux":
+            environ["GRPC_RUNTESTS_ARCHITECTURE"] = self.args.arch
         return environ
 
     def post_tests_steps(self):
@@ -606,81 +615,6 @@ class CLanguage(object):
         return self.lang_suffix
 
 
-# This tests Node on grpc/grpc-node and will become the standard for Node testing
-class RemoteNodeLanguage(object):
-    def __init__(self):
-        self.platform = platform_string()
-
-    def configure(self, config, args):
-        self.config = config
-        self.args = args
-        # Note: electron ABI only depends on major and minor version, so that's all
-        # we should specify in the compiler argument
-        _check_compiler(
-            self.args.compiler,
-            [
-                "default",
-                "node0.12",
-                "node4",
-                "node5",
-                "node6",
-                "node7",
-                "node8",
-                "electron1.3",
-                "electron1.6",
-            ],
-        )
-        if self.args.compiler == "default":
-            self.runtime = "node"
-            self.node_version = "8"
-        else:
-            if self.args.compiler.startswith("electron"):
-                self.runtime = "electron"
-                self.node_version = self.args.compiler[8:]
-            else:
-                self.runtime = "node"
-                # Take off the word "node"
-                self.node_version = self.args.compiler[4:]
-
-    # TODO: update with Windows/electron scripts when available for grpc/grpc-node
-    def test_specs(self):
-        if self.platform == "windows":
-            return [
-                self.config.job_spec(
-                    ["tools\\run_tests\\helper_scripts\\run_node.bat"]
-                )
-            ]
-        else:
-            return [
-                self.config.job_spec(
-                    ["tools/run_tests/helper_scripts/run_grpc-node.sh"],
-                    None,
-                    environ=_FORCE_ENVIRON_FOR_WRAPPERS,
-                )
-            ]
-
-    def pre_build_steps(self):
-        return []
-
-    def build_steps(self):
-        return []
-
-    def build_steps_environ(self):
-        """Extra environment variables set for pre_build_steps and build_steps jobs."""
-        return {}
-
-    def post_tests_steps(self):
-        return []
-
-    def dockerfile_dir(self):
-        return "tools/dockerfile/test/node_jessie_%s" % _docker_arch_suffix(
-            self.args.arch
-        )
-
-    def __str__(self):
-        return "grpc-node"
-
-
 class Php7Language(object):
     def configure(self, config, args):
         self.config = config
@@ -869,13 +803,6 @@ class PythonLanguage(object):
 
         # TODO: Supported version range should be defined by a single
         # source of truth.
-        python37_config = _python_config_generator(
-            name="py37",
-            major="3",
-            minor="7",
-            bits=bits,
-            config_vars=config_vars,
-        )
         python38_config = _python_config_generator(
             name="py38",
             major="3",
@@ -934,11 +861,9 @@ class PythonLanguage(object):
             else:
                 # Default set tested on master. Test oldest and newest.
                 return (
-                    python37_config,
+                    python38_config,
                     python312_config,
                 )
-        elif args.compiler == "python3.7":
-            return (python37_config,)
         elif args.compiler == "python3.8":
             return (python38_config,)
         elif args.compiler == "python3.9":
@@ -957,7 +882,6 @@ class PythonLanguage(object):
             return (python39_config,)
         elif args.compiler == "all_the_cpythons":
             return (
-                python37_config,
                 python38_config,
                 python39_config,
                 python310_config,
@@ -1327,7 +1251,6 @@ with open("tools/run_tests/generated/configs.json") as f:
 _LANGUAGES = {
     "c++": CLanguage("cxx", "c++"),
     "c": CLanguage("c", "c"),
-    "grpc-node": RemoteNodeLanguage(),
     "php7": Php7Language(),
     "python": PythonLanguage(),
     "ruby": RubyLanguage(),
@@ -1744,7 +1667,7 @@ argp.add_argument(
         "gcc12_openssl309",
         "gcc_musl",
         "clang6",
-        "clang16",
+        "clang17",
         # TODO: Automatically populate from supported version
         "python3.7",
         "python3.8",
@@ -1756,12 +1679,12 @@ argp.add_argument(
         "pypy3",
         "python_alpine",
         "all_the_cpythons",
-        "electron1.3",
-        "electron1.6",
         "coreclr",
         "cmake",
         "cmake_ninja_vs2019",
+        "cmake_ninja_vs2022",
         "cmake_vs2019",
+        "cmake_vs2022",
         "mono",
     ],
     default="default",
